#!/usr/bin/env python
# -*- coding: utf-8 -*-#
#
#
# Copyright (c) 2019 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
import unittest
from oauth1.oauth import OAuth
from oauth1.oauth import OAuthParameters
import oauth1.authenticationutils as authenticationutils
import oauth1.coreutils as Util
from os.path import dirname, realpath, join, os

from oauth1.signer import OAuthSigner
from OpenSSL import crypto



class UtilsTest(unittest.TestCase):




    def test_load_signing_key_should_return_key(self):
        if os.path.exists('./test_key_container.p12'):
            key_container_path = "./test_key_container.p12";
            key_password = "Password1";

            signing_key = authenticationutils.load_signing_key(key_container_path, key_password)
            self.assertTrue(signing_key.check)
       
            bits = signing_key.bits()
            self.assertEqual(bits, 2048)

            private_key_bytes = crypto.dump_privatekey(crypto.FILETYPE_PEM, signing_key)
            self.assertTrue(private_key_bytes)
        else:
            print("Please add a ./test_key_container.p12 file to enable key tests")

        
    def test_validate_url(self):
        self.assertFalse(Util.validate_url("whats this rubbish"))
        self.assertTrue(Util.validate_url("https://developer.mastercard.com"))

        
if __name__ == '__main__':
    unittest.main()
